plot_timeser3 <-
function(datrec,valrec,valrec2=NaN,datobs=NaN,valobs=NaN,smwindow=0,xlim=NaN,ylim=NaN)
{
# plot matrix valrec considered as resolved in time (given by valrec)
# valrec is a set of three values: first = central value, 
# second = lower error bar (positive value to substract to the central value)
# third = upper bar (positive value to add to the central value)
# if datobs and valobs are not NaN, we had the corresponding values of the observations
# datobs is a vector, valobs is a matrix where each column must correspond 
# to each 3th column of recval
# if smwindow > 0, we add a smoothed line to the central value using the window 
# defined by the value of smwindow (1 to third size of time series)
# xlim is a pair lower and upper value for the time scale 
# ylim is a vector of size m*2 with min and max values for vertical axes: values 1 and 2 for variable 1, values 3 and 4 for variable 2 ... 
# initialization

ne<-nrow(valrec)
me<-ncol(valrec)
me3<-floor(me/3)
if ((me3*3)<me) stop ("valrec matrix has not a number of rows which may be divided by 3")
op<-par(cex.axis=1.3,cex.lab=1.3,cex.main=1.5)

kk<-0
if (is.na(xlim[1])) {xlim=c(min(datrec),max(datrec))}
if (is.na(ylim[1])) {ylim=rep(NA,2*me3)}
if (length(ylim)<2*me3) {ylim=rep(ylim[1:2],me3)}

for (k in seq(1,me,3))
{
	kk<-kk+1
	ylim0=ylim[(kk*2-1):(kk*2)]
	if (is.na(ylim0[1])) {ylim0=c(min(valrec[,k]-valrec[,k+1],na.rm=T),max(valrec[,k]+valrec[,k+2],na.rm=T))}

# plot central value
	plot(datrec,valrec[,k],type='l',xlab=names(datrec),ylab=colnames(valrec)[k], xlim=xlim,ylim=ylim0,cex.main=2,cex.axis=1.3,cex.lab=1.3)
	
# Plot upper and lower bars
	yi<-valrec[,k]-valrec[,k+1]
	ys<-valrec[,k]+valrec[,k+2]
	for (i in 2:ne) {	
		dm<-valrec[i-1,k]
		if (is.na(dm)) {dm=mean(valrec[,k],na.rm=TRUE)} 
		if (is.na(yi[i])) {yi[i]<-dm}
		if (is.na(ys[i])) {ys[i]<-dm} 
	}

# smoothing
x=c(datrec,rev(datrec))		
fw<-min(0.5,1./max(1,smwindow))
sm1=loess(yi~datrec,na.action=na.omit,degree=2,span=fw)
sm2=loess(rev(ys)~rev(datrec),na.action=na.omit,degree=2,span=fw)
y=c(sm1$fitted,sm2$fitted)
polygon(x,y,col="gray",density=50,border=TRUE)

# plot lower error bar
	if (length(valrec2)>1) {
		yi<-valrec[,k]-valrec2[,k+1]
		ys<-valrec[,k]+valrec2[,k+2]
		for (i in 2:ne) {
			dm<-valrec[i-1,k]
			if (is.na(dm)) {dm=mean(valrec[,k],na.rm=TRUE)} 
			if (is.na(yi[i])) {yi[i]<-dm}
			if (is.na(ys[i])) {ys[i]<-dm} 
		}
		x=c(datrec,rev(datrec))		
		sm1=loess(yi~datrec,na.action=na.omit,degree=2,span=fw)
		sm2=loess(rev(ys)~rev(datrec), na.action=na.omit,degree=2,span=fw)
		y=c(sm1$fitted,sm2$fitted)
		polygon(x,y,col="gray",density=100,border=FALSE)
	}
	
# plot central value again
	lines(datrec[1:ne],valrec[1:ne,k],cex=2,col="black")


# Plot observations
	if (length(datobs)>1) {
		lines(datobs,valobs[,kk],col="orange",type='l',lwd=1)
	}

# Add loess smoother on the central value
	if (smwindow>0) {
		fw<-1./smwindow
		sm<-loess(valrec[,k]~datrec,na.action=na.omit,degree=2,span=fw)
		lines(sm$x,sm$fitted,col="blue",lwd=3)
    if (length(datobs)>1) {
      sm<-loess(valobs[,kk]~datobs,na.action=na.omit,degree=2,span=fw)
		  lines(sm$x,sm$fitted,col="red",lwd=3)
    }
	}

	grid(col="black")
}
par(op)	
message="well done"
return(message)
}
