recGAM <-
function(ass,clim,fass,fclim=FALSE,p=1,outfile=NULL)
{

# Initialisation

library(mgcv)
library(vegan)

if (p>6) {p<-6}
na<-nrow(ass)
ma<-ncol(ass)
nc<-nrow(clim)
mc<-ncol(clim)
mc3=mc*3
nfa<-nrow(fass)
mfa<-ncol(fass)
if (identical(na,nc)==FALSE) {stop ("both ass & clim matrices have not same number of rows")}
if (identical(mfa,ma)==FALSE) {stop ("both ass & fass matrices have not same number of columns")}
nfc<-0
mfc<-0
option="extrapolation"
GAM<-list(title="Transfer function estimates by GAM method")
GAM$rmse<-rep(0,mc)
GAM$r2<-rep(0,mc)
GAM$clim<-matrix(0,nc,mc3)
GAM$fclim<-matrix(0,nfa,mc3)
if (is.logical(fclim)==FALSE)
	{
	nfc<-nrow(fclim)
	mfc<-ncol(fclim)
	if (identical(nfc,nfa)==FALSE) stop ("both fclim & fass matrices have not same number of rows")
	option="verification"
	GAM$rmsep<-rep(0,mc)
	GAM$r2p<-rep(0,mc)
	GAM$CE<-rep(0,mc)
	}

if (!is.null(outfile)) 
	{
	fgraph=paste(outfile,".pdf",sep="")
	ftext=paste(outfile,".txt",sep="")
	sink(file=ftext)
	pdf(file=fgraph)
	}

cat("TRANSFER FUNCTION : Generalized Adaptative Model (GAM)\n")
cat("--------------------------------------------------------------------------------\n")
cat("\nOption : ",option,"\n")

cam<-cca(ass)
z.ass<-cam$CA$u[,1:p]
mat<-predict(cam,fass,model="CA",type="wa")
z.fass<-mat[,1:p]

if (p<6) 
	{ 
	for(i in (p+1):6)
		{
	        z.ass<-cbind(z.ass, z.ass[,p])
		z.fass<-cbind(z.fass, z.fass[,p])
		}
	}	

#	z.ass[,(p+1):6]<-z.ass[,p]
#	z.fass[,(p+1):6]<-z.fass[,p]

# climatic variable loop

cat("In the verification step, r2p (or reduction of error) compares the predictions to the calibration period climatology\n") 
cat("In the verification step, CE (or coefficient of efficiency) compares the predictions to the verification period climatology\n") 

for (j in 1:mc)
	{
# calibration
	cat("\nDependent Variable : ",colnames(clim[j]),"\n")
	cat("---------------------------------------------\n")
	vd<-clim[,j]
	x1<-z.ass[,1];x2<-z.ass[,2];x3<-z.ass[,3];x4<-z.ass[,4];x5<-z.ass[,5];x6<-z.ass[,6]
	gamm<-gam(vd~s(x1)+s(x2)+s(x3)+s(x4)+s(x5)+s(x6))
	print(summary(gamm))
	mat=data.frame(x1=z.ass[,1],x2=z.ass[,2],x3=z.ass[,3],x4=z.ass[,4],x5=z.ass[,5],x6=z.ass[,6])
	yp<-predict(gamm,mat)
	GAM$clim[,(j-1)*3+1]<-yp
	GAM$rmse[j]<-mean((clim[,j]-yp)^2)^0.5
	GAM$clim[,(j-1)*3+2]<-GAM$rmse[j]
	GAM$clim[,(j-1)*3+3]<-GAM$rmse[j]
	GAM$r2[j]<-1-mean((clim[,j]-yp)^2)/var(clim[,j])
	cat("R2 = ",GAM$r2[j],"  -- RMSE = ",GAM$rmse[j],"calculated on ",na,"  observations\n")
	smin<-min(clim[,j])
	smax<-max(clim[,j])
	plot(c(smin,smax),c(smin,smax), type='l',xlab=paste(colnames(clim)[j],"calib"), ylab="Predicted GAM", main="",col="green")
	points(clim[,j],GAM$clim[,(j-1)*3+1],pch=19,col='blue')
	
# verification

	if (option=="verification")
		{
		mat=data.frame(x1=z.fass[,1],x2=z.fass[,2],x3=z.fass[,3],x4=z.fass[,4],x5=z.fass[,5],x6=z.fass[,6])
		yp<-predict(gamm,mat)
		GAM$rmsep[j]<-mean((fclim[,j]-yp)^2)^0.5
		GAM$r2p[j]<-1-mean((fclim[,j]-yp)^2)/var(fclim[,j])
		GAM$CE[j]<-1-mean((fclim[,j]-yp)^2)/var(clim[,j])
		cat("R2p (RE) = ",GAM$r2p[j]," -- CE = ",GAM$CE[j],"  -- RMSEp = ",GAM$rmsep[j],"calculated on ",nfa,"  observations\n")
		GAM$fclim[,(j-1)*3+1]<-yp
		GAM$fclim[,(j-1)*3+2]<-GAM$rmsep[j]
		GAM$fclim[,(j-1)*3+3]<-GAM$rmsep[j]
		smin<-min(cbind(t(clim[,j]),t(fclim[,j])))
		smax<-max(cbind(t(clim[,j]),t(fclim[,j])))
		plot(c(smin,smax),c(smin,smax), type='l',xlab=paste(colnames(clim)[j]," calib (blue) / verif (red)"), ylab="Predicted GAM", main="",col="green")
		points(clim[,j],GAM$clim[,(j-1)*3+1],pch=19,col='blue')
		points(fclim[,j],GAM$fclim[,(j-1)*3+1],col='red',pch=21)
		}
	 else
		{
# extrapolation
		cat("the estimated climate is put in the GAM$fclim matrix\n")
		matf<-data.frame(x1=z.fass[,1],x2=z.fass[,2],x3=z.fass[,3],x4=z.fass[,4],x5=z.fass[,5],x6=z.fass[,6])
		yp<-predict(gamm,matf)
		GAM$fclim[,(j-1)*3+1]<-yp
		GAM$fclim[,(j-1)*3+2]<-GAM$rmse[j]
		GAM$fclim[,(j-1)*3+3]<-GAM$rmse[j]
		}
	}
# Sauver toute la liste GAM
	coln<-rep(NA,mc3)
	for (j in 1:mc) 
		{
		coln[(j-1)*3+1]<-colnames(clim)[j]
		coln[(j-1)*3+2]<-paste(colnames(clim)[j],'_i',sep="")
		coln[(j-1)*3+3]<-paste(colnames(clim)[j],'_s',sep="")
		}
	colnames(GAM$clim)<-coln
	colnames(GAM$fclim)<-coln
	rownames(GAM$clim)<-rownames(clim)
	rownames(GAM$fclim)<-rownames(fass)	
	cat("\nImpression de la liste GAM\n")
	print(GAM)
	if (!is.null(outfile)) 
		{
		dev.off()
		sink()
		}

return(GAM)
}
