recPLS <-
function(ass,clim,fass,fclim=FALSE,p=0,outfile=NULL)
{

# Initialisation

library(pls)
na<-nrow(ass)
ma<-ncol(ass)
nc<-nrow(clim)
mc<-ncol(clim)
mc3=mc*3
nfa<-nrow(fass)
mfa<-ncol(fass)
if (identical(na,nc)==FALSE) {stop ("both ass & clim matrices have not same number of rows")}
if (identical(mfa,ma)==FALSE) {stop ("both ass & fass matrices have not same number of columns")}
nfc<-0
mfc<-0
option="extrapolation"
PLS<-list(title="Transfer function estimates by PLS method")
PLS$rmse<-rep(0,mc)
PLS$r2<-rep(0,mc)
PLS$clim<-matrix(0,nc,mc3)
PLS$fclim<-matrix(0,nfa,mc3)
PLS$rmsep<-rep(0,mc)
PLS$r2p<-rep(0,mc)
if (is.logical(fclim)==FALSE) {
	nfc<-nrow(fclim)
	mfc<-ncol(fclim)
	if (identical(nfc,nfa)==FALSE) stop ("both fclim & fass matrices have not same number of rows")
	option="verification"
  PLS$CE<-rep(0,mc)
	}

if (!is.null(outfile)) {
	fgraph=paste(outfile,".pdf",sep="")
	ftext=paste(outfile,".txt",sep="")
	sink(file=ftext)
	pdf(file=fgraph)
}

cat("TRANSFER FUNCTION : Partial Least Squares (PLS) method\n")
cat("--------------------------------------------------------------------------------\n")
cat("\nOption : ",option,"\n")

# climatic variable loop

cat("In the verification step, r2p (or reduction of error) compares the predictions to the calibration period climatology\n") 
cat("In the verification step, CE (or coefficient of efficiency) compares the predictions to the verification period climatology\n") 


for (j in 1:mc)
{

# calibration

	cat("\nDependent Variable : ",colnames(clim[j]),"\n")
	cat("----------------------------------------\n")
	mat<-data.frame(cbind(ass,vd=clim[,j]))
	fmla<-as.formula("vd ~ .")
	plsm<-mvr(fmla,ncomp=min(na-10,ma),data=mat,method="kernelpls",validation="LOO")
  print(dim(plsm$fitted.values))
	print(summary(plsm))
  ps=which.min(plsm$validation$PRESS)
  ps=max(1,ps)
  ps=min(ma,ps)
	cat("Nb components retained (minimisation of RMSEP)= ",ps,"\n")
  if (p>0) {
    ps=p
    cat("Nb components constrained by user = ",ps,"\n")
  }
	PLS$clim[,(j-1)*3+1]<-plsm$fitted.values[,1,ps]
	PLS$rmse[j]<-mean((clim[,j]-PLS$clim[,(j-1)*3+1])^2)^0.5
	PLS$r2[j]<-1-mean((clim[,j]-PLS$clim[,(j-1)*3+1])^2)/var(clim[,j])
  PLS$rmsep[j]=sqrt(plsm$validation$PRESS[ps]/na)
  PLS$r2p[j]=1-plsm$validation$PRESS[ps]/plsm$validation$PRESS0
  PLS$clim[,(j-1)*3+2]<-PLS$rmsep[j]
	PLS$clim[,(j-1)*3+3]<-PLS$rmsep[j]
	cat("R2 = ",PLS$r2[j],"  -- RMSE = ",PLS$rmse[j],"calculated on ",na,"  observations\n")
  cat("R2p = ",PLS$r2p[j],"  -- RMSEp = ",PLS$rmsep[j]," by Jackknife\n")
	smin<-min(clim[,j])
	smax<-max(clim[,j])
	plot(c(smin,smax),c(smin,smax), type='l',xlab=paste(colnames(clim)[j],"calib"), ylab="Predicted PLS", main="",col="green")
	points(clim[,j],PLS$clim[,(j-1)*3+1],pch=19,col='blue')
# verification

	if (option=="verification")
		{
		yp=predict(plsm,newdata=fass,ncomp=ps)
		PLS$rmsep[j]<-mean((fclim[,j]-yp[,1,1])^2)^0.5
		PLS$r2p[j]<-1-mean((fclim[,j]-yp[,1,1])^2)/var(fclim[,j])
		PLS$CE[j]<-1-mean((fclim[,j]-yp[,1,1])^2)/var(clim[,j])
    cat("Verification on the independent dataset provided \n")
		cat("R2p (RE) = ",PLS$r2p[j],"  -- CE = ",PLS$CE[j],"  -- RMSEp = ",PLS$rmsep[j],"calculated on ",nfa,"  observations\n")
		PLS$fclim[,(j-1)*3+1]<-yp[,1,1]
		PLS$fclim[,(j-1)*3+2]<-PLS$rmsep[j]
		PLS$fclim[,(j-1)*3+3]<-PLS$rmsep[j]
		smin<-min(cbind(t(clim[,j]),t(fclim[,j])))
		smax<-max(cbind(t(clim[,j]),t(fclim[,j])))
		plot(c(smin,smax),c(smin,smax), type='l',xlab=paste(colnames(clim)[j]," calib (blue) / verif (red)"), ylab="Predicted PLS", main="",col="green")
		points(clim[,j],PLS$clim[,(j-1)*3+1],pch=19,col='blue')
		points(fclim[,j],PLS$fclim[,(j-1)*3+1],col='red',pch=21)
		} 
	else
		{
# extrapolation
		yp=predict(plsm,newdata=fass,ncomp=ps)
		PLS$fclim[,(j-1)*3+1]<-yp[,1,1]
		PLS$fclim[,(j-1)*3+2]<-PLS$rmsep[j]
		PLS$fclim[,(j-1)*3+3]<-PLS$rmsep[j]
		}
	}
	coln<-rep(NA,mc3)
	for (j in 1:mc) {
		coln[(j-1)*3+1]<-colnames(clim)[j]
		coln[(j-1)*3+2]<-paste(colnames(clim)[j],'_i',sep="")
		coln[(j-1)*3+3]<-paste(colnames(clim)[j],'_s',sep="")
	}
	colnames(PLS$clim)<-coln
	colnames(PLS$fclim)<-coln
	rownames(PLS$clim)<-rownames(clim)
	rownames(PLS$fclim)<-rownames(fass)	
	cat("\nImpression de la liste PLS\n")
	print(PLS)
	if (!is.null(outfile)) {
		dev.off()
		sink()
		sink()
		sink()
	}
return(PLS)
}
