\name{pftscores}
\alias{pftscores}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{ calculates pft, biome scores and assigned biome to a matrix of assemblages }
\description{
  Calculates pft scores using a tax2pft conversion matrix and taxcar/pftassign matrices to sort the pft according to their climatic characteristics, then biome scores using a pft2biom conversion matrix and finally assign the biome for which the biome score is maximum   
}
\usage{
output=pftscores(ass,tax2pft,taxcar,pftassign,pft2biom,transf=0,outfile=NULL)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ass}{ \code{ass} is the assembage matrix }
  \item{tax2pft}{\code{tax2pft} = conversion matrix with taxa as rows and pft in columns : ass * tax2pft = pft  (p pft = columns)}
  \item{taxcar}{ \code{taxcar} = vector of values (-1, 0, -1) according to a characteristic of the taxon: e.g. for temperature, taxa with -1 are cold, with 0 are undetermined, with 1 are warm}
  \item{pftassign}{ \code{pftassign} = matrix(3,p); row 1 gives the number of the pft to which it must be assigned if the cold scores dominate; row 2 gives the number of the pft to which it must be assigned if there is no dominance; row 3 gives the number of the pft to which it must be assigned if the warm scores dominate}
  \item{pft2biom}{ \code{pft2biom} = conversion matrix from pft to biome scores: each element is 1 if the pft belongs to the taxon, otherwise 0}
  \item{transf}{ \code{transf} = transformation mode for the data: 0 (no transformation), 1 (square root), 2 (logarithm)}
}
\details{
  void
}
\value{
  output is a list of components
  PFT$scores is the matrix of scores for each PFT and each assemblage
  PFT$taxpos is sum of the taxa (eventually transformed by sqrt or log) with taxcar>0
  PFT$taxneg is sum of the taxa (eventually transformed by sqrt or log) with taxcar<0
  PFT$biomsco is the matrix of scores for each biome and each assemblage
  PFT$biome is the vector of biome assigned for each assemblage
}
\references{ ~ ~ }
\author{ J. Guiot }
\note{ void
}
\seealso{ ~~objects to See Also as \code{\link{help}}, ~~~ }
\examples{
x=read.table('data/tax2pft.txt',header=T,row.names=1)
po=read.table('data/ss700po.txt',header=T,row.names=1)
tax2pft=x[4:nrow(x),2:ncol(x)]
pftassign=x[1:3,2:ncol(x)]
taxcar=x[4:nrow(x),1]
pft=pftscores(po,tax2pft,taxcar,pftassign,pft2biom,transf=1)
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ biomes, pollen, plant functional types }

