\name{recANNb}
\alias{recANNb}
\title{ transfer function using the bootstrap artificial neural networks }
\description{
Calculate a non-linear regression between environmental variables and assemblages based on neural networks; robustess of the results are tested using bootstrap replications.
}
\usage{
output=recANNb(xmat,ymat,xnewmat,ynewmat=FALSE,p=0,k1,ntiter=1000,ncas=100,outfile=NULL)
}
\arguments{
  \item{xmat}{ \code{xmat} is the matrix of the predictors (assemblages) }
  \item{ymat}{ \code{ymat} is the matrix of the predictands (environment) }
  \item{xnewmat}{ \code{xnewmat} is the assemblages matrix  for verification or prediction }
  \item{ynewmat}{ \code{ynewmat} is the environmental matrix corresponding to xnewmat, if verification is wanted; if it is a prediction (reconstruction), assign to FALSE (default) }
  \item{p}{ \code{p} is the number of principal components used; default = 0, e.g. no transformation of the assemblages}
  \item{k1}{ \code{k1} is the number of neurones in the intermediate layer}
  \item{ntiter}{ \code{ntiter} is the number of simulations for each bootstrap case; default=1000}
  \item{ncas}{ \code{ncas} is the number of bootstrap replications; default=100}
  \item{outfile}{ \code{outfile} is the filename for the log and graphics }
}
\details{
    The script uses "nnet" of library "nnet" for ANN fitting. The environmental variables are processed as a whole. To decrease the number of parameters, it is possible to transform the assemblages into principal components and to use a subset of p components. For each bootstrap replication, the subset of observations randomly taken are considered as calibration dataset and the remaining ones as verification dataset. The calibration subset is used to train the ANN which is applied afterwards to the verification subset. Statistics are calculated on both subsets. Summary statistics are obtained from the 2.5th, 50th and 97.5th percentiles. Sensitivity fonctions of the environmental variables to the various taxa (or PCs) are also displayed with their bootstrap confidence intervals. }
\value{
output list contains: 
  rmse, r2, calculated on the calibration data; 
  clim, the estimates (with 95% confidence intreval) of the predictands used for calibration;
  fclim the estimates of the new environmental matrix; 
  if there is verification, it contains also: 
    rmsep, RE (or r2p) and CE (calculated on the independent data). 
  RE is the variance explained as compared with the calibration average and CE is the variance explained as compared with the verification average.
}
\references{ ~ ~ }
\author{ J. Guiot }
\note{ void
}
\examples{
output=recANNb(ss700po,ss700cl,fospo%,k1=4)
}

\keyword{ multivariate statistics}
\keyword{ artificial neural network} 
\keyword{ principal components}
\keyword{ transfer function}
\keyword{ bootstrap}

