\name{recWAPLS}
\alias{recWAPLS}
\title{ transfer function using the WAPLS method }
\description{
Calculate a weighted average partial least square (WAPLS) regression between environmental variables and assemblages; regression coefficients are used for prediction. WAPLS is to PLS what is correspondence analysis to principal component analysis.
}
\usage{
output=recWAPLS(xmat,ymat,xnewmat,ynewmat=FALSE,p=10,outfile=NULL)
}
\arguments{
  \item{xmat}{ \code{xmat} is the matrix of the predictors (assemblages) }
  \item{ymat}{ \code{ymat} is the matrix of the predictands (environment) }
  \item{xnewmat}{ \code{xnewmat} is the assemblages matrix  for verification or prediction }
  \item{ynewmat}{ \code{ynewmat} is the environmental matrix corresponding to xnewmat, if verification is wanted; if it is a prediction (reconstruction), assign to FALSE }
  \item{p}{ \code{p} is the maximum number of principal factors used; default = 10}
  \item{outfile}{ \code{outfile} is the filename for the log and graphics }
}
\details{
    The script uses "mvr" of library "pls" for PLS modelling. PLS method is applied on transformed matrices as proposed by Ter Braak (1993). Each environmental variable is processed independently. A maximum of p principal factors is used; the final number of PCs is selected by using a cross-validation scheme ("LOO": leave one out). Note also that a principal factor here is not the component which maximises the predictors inerty, but the co-inerty between predictands and predictands }
\value{
output list contains: 
  rmse, r2, calculated on the calibration data; 
  clim, the estimates (with 95% confidence intreval) of the predictands used for calibration;
  fclim the estimates of the new environmental matrix; 
  if there is verification, it contains also: rmsep, RE (or r2p) and CE (calculated on the independent data). 
  RE is the variance explained as compared with the calibration average and CE is the variance explained as compared with the verification average.
}
\references{ ~ ~ }
\author{ J. Guiot }
\note{ void
}
\examples{
output=recWAPLS(ss700po,ss700cl,fospo%,p=10)
}

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ multivariate statistics } 
\keyword{ WAPLS regression }
\keyword{ correspondence analyis } 
\keyword{ transfer function}

