\name{splitdata2}
\Rdversion{1.1}
\alias{splitdata2}
\title{ Split the input data matrices into calibration and verification matrices }
\description{
Three input matrices are necessary: assemblages, climate, coordinates. 
The three matrices have the same number of rows and different number of columns.
Splidata2 sort data according to the first pc of the climate and randomly select nverif observations in the sorted pc1 with a safety radius (max 10) to avoid that verifications observations are too close to the calibrations observations so the observations randomly drawn along the gradient of the first PC are marked as "verif" in split$obsrole. Their neighbours (from rank 1 to radius) are marked as "excl" and the other ones as "calib"
Rem. eighbour is in terms of rank and not in term of geographical distance or pc-distance.   
}
\usage{
output=splitdata(ass,clim,coord,nverif,radius)
}
%- maybe also 'usage' for other objects documented here.
\arguments{
  \item{ass}{ is the assemblage data, i.e. one column per taxon }
  \item{clim}{ is the climate data, same number of rows than ass }
  \item{coord}{ is the coordinate data, longitude, latitude, altitude, same number of rows than ass }
   \item{nverif}{ The \code{nverif} observations are randomly taken from the dataset for verification }
   \item{radius}{ A safety \code{radius} (units = number of observations) is defined around each verification observation along the first PC; all the radius observations below and above the verification observation (along PC1) are marked as "excl"}
}
\details{
  The climate matrix is transformed into principal components and the observations are sorted according to the first PC.
  the selection of observations is based on the gradient of the first PC; 
So the randomly taken observattions are verifications observations, the observations within the radius are excluded (not used for calib nor verif), the remaining ones are used for calibration
Output = list "split"
}
\value{
  split is the list with components : 
  output$assc = matrix of assemblages for calibration; 
  output$assv = matrix of assemblages for verification; 
  output$climc = matrix of climate for calibration; 
  output$climv = matrix of climate for verification; 
  output$coordc = matrix of coordinates for calibration; 
  output$coordv = matrix of coordinates for verification; 
  output$obsrole = role of the observations (calib, verif, excl)
}
\references{ }
\author{ J. Guiot }
\note{ }
\seealso{ objects to See Also as \code{\link{help}} }
\examples{ output=splitdata2(ss700po,ss700cl,ss700co,50,) }

% Add one or more standard keywords, see file 'KEYWORDS' in the
% R documentation directory.
\keyword{ random, cross-validation }

